program BOS_to_BASM;
{$APPTYPE CONSOLE}
uses
  SysUtils,
  classes,
  inifiles,
  Cob_Format in 'Cob_Format.pas',
  BOSCompilerU in 'BOSCompilerU.pas',
  FileHandlingU in 'FileHandlingU.pas',
  PreProcessorU in 'PreProcessorU.pas',
  ScannerU in 'ScannerU.pas';

var
  EnableBASMExtentions : boolean;
  AssemblerExeName : string;
  AssemblerParams : string;
  AssemblerOutputFile  : string;
  CompileAndDoNotAssemble : boolean;
  PauseOnException : boolean;
  PauseAtEnd : boolean;
Procedure ReadSettings;
var
  IniFile : TIniFile;
begin
IniFile := TIniFile.create(ChangeFileExt(ParamStr(0),'.ini'));
try
  IncludePaths := TStringlist.create;
  IncludePaths.Duplicates := DupIgnore;
  ReadSemiColonDelimitedList( IniFile.ReadString( 'Settings', 'IncludePaths', '' ), IncludePaths );
  SearchPaths := TStringlist.create;
  SearchPaths.Duplicates := DupIgnore;
  ReadSemiColonDelimitedList( IniFile.ReadString( 'Settings', 'SearchPaths', '' ), SearchPaths );
  SearchPaths.Add( ExtractFILePath( Paramstr( 0 ) ) );
  EnableBASMExtentions := IniFile.ReadBool( 'Settings', 'EnableBASMExtentions', true );
  AssemblerExeName := IniFile.ReadString( 'Settings', 'AssemblerExeName', 'BASM.exe' );
  AssemblerParams := IniFile.ReadString( 'Settings', 'AssemblerParams', '-l -s -o0' );
  AssemblerOutputFile := IniFile.ReadString( 'Settings', 'AssemblerOutputFile', '' );
  CompileAndDoNotAssemble := IniFile.ReadBool( 'Settings', 'CompileAndDoNotAssemble', false );
  PauseOnException := IniFile.ReadBool( 'Settings', 'PauseOnException', true );
  PauseAtEnd := IniFile.ReadBool( 'Settings', 'PauseAtEnd', false );
finally
  IniFile.free;
end;
end; {ReadSettings}

var
  Filename,FileNameRootPath : string;
  index : integer;
begin
  ThousandSeparator := ',';
  DecimalSeparator := '.';
try
  if ParamCount < 1 then
    Raise Exception.createfmt( 'Usage: %s <bos file>', [ ExtractFilename( ParamStr( 0 ) ) ] );
  SetCurrentDir( ExtractFilePath( ParamStr( 0 ) ) );
  for index := 1 to ParamCount do
    try try
      ReadSettings;
      Filename := FindFile( ParamStr( index ) );
      if not FileExists(Filename) then
        Raise Exception.createfmt( 'File %s does not exist', [ Filename ] );
      Filename := ExtractRelativePath( IncludeTrailingBackslash( GetCurrentDir ), Filename);
      FileNameRootPath := ExtractFilePath( Filename );
      if FileNameRootPath <> '' then
        SearchPaths.Insert( 0, FileNameRootPath );
      CompileBOS( Filename, EnableBASMExtentions , CompileAndDoNotAssemble,
                  AssemblerExeName, AssemblerParams, AssemblerOutputFile );
    finally
      Writeln;
      FreeAndNil( IncludePaths );
      FreeAndNil( SearchPaths );
    end;
    except
      On e : Exception do
        begin
        writeln( e.message );
        if PauseOnException and not PauseAtEnd then
          readln;
        end;
    end;
except
  On e : Exception do
    begin
    writeln( e.message );
    if PauseOnException and not PauseAtEnd then
      readln;
    end;
end;
if PauseAtEnd then
  readln;
end.